import pygame as pg
import scipy.stats as ss
import numpy as np

rho = float(input('rho = '))
n = int(input('n = '))

pg.init()
wt = int(3000 / n)
pg.display.set_caption('Simulation of Sample Correlation')
screen = pg.display.set_mode(size=(700, 700))
screen.fill((255,255,255))
pg.display.flip()
#
#          母数の表示用文字列
#
my_font = pg.font.SysFont(None, 32)
img_str1 = my_font.render(f'rho = {rho},  n = {n}', True,
                          (0,0,0), (255,255,255))

my_font_L = pg.font.SysFont(None, 40)
img_str_L = my_font_L.render('Next -> key N,    End -> key E', True,
                             (0,0,0), (255,255,255))
rect_str_L = img_str_L.get_rect()

ck = True
while ck:
    screen.fill((255,255,255))
    #
    #          データのサンプリング
    #
    data = ss.multivariate_normal.rvs(mean=[0, 0], 
                              cov=[[1, rho],[rho, 1]], size=n)
    #
    #          相関係数の計算
    #
    results = ss.pearsonr(data.T[0], data.T[1])
    #
    #          信頼区間の計算
    #
    vL, vU = results.confidence_interval(0.95)

    v_max = np.max(data)
    v_min = np.min(data)
    #
    #          点の描画用スケーリング関数
    #
    def scale_v(v):
        return 100 + (700 - 200) * (v - v_min) / (v_max - v_min)

    #
    #           散布図
    #
    for d in data:
        pg.draw.circle(screen, (0,0,250), (scale_v(d[0]), 710 - scale_v(d[1])),
                       7, 3)
        pg.display.flip()
        pg.time.wait(wt)        #    各点の描画時間間隔
    #
    #           母数の表示
    #
    screen.blit(img_str1, (50, 10))
    #
    #           相関係数、ｐ値、区間推定の表示
    #
    img_str2 = my_font.render(f'r = {results.statistic:.3f},  p = {results.pvalue:.5f}' +
                f',  95%CI = [{vL:.3f}, {vU:.3f}]',
                True, (0,0,0), (255,255,255))
    screen.blit(img_str2, (50, 40))
    #
    #           キー操作のメッセージ表示
    #
    screen.blit(img_str_L, (350 - (rect_str_L.width//2),
                                   700 - (rect_str_L.height*2)) )
    pg.display.flip()
    
    ck1 = True
    while ck1:
        for e in pg.event.get():      #   キーイベントのチェック
            if e.type == pg.KEYDOWN:
                if e.key == pg.K_n:
                    ck1 = False
                elif e.key == pg.K_e:
                    ck = False
                    ck1 = False

    screen.fill((255,255,255))       #   ホワイトアウト
    pg.display.flip()

pg.quit()
